@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: conf.c,v 1.3 1999/01/10 21:53:44 ezk Exp $
+ * $Id: conf.c,v 1.7 2000/02/16 13:52:57 ezk Exp $
  *
  */
 
@@ -82,6 +82,7 @@ static int gopt_cache_duration(const char *val);
 static int gopt_cluster(const char *val);
 static int gopt_debug_options(const char *val);
 static int gopt_dismount_interval(const char *val);
+static int gopt_full_os(const char *val);
 static int gopt_fully_qualified_hosts(const char *val);
 static int gopt_hesiod_base(const char *val);
 static int gopt_karch(const char *val);
@@ -97,8 +98,10 @@ static int gopt_map_type(const char *val);
 static int gopt_mount_type(const char *val);
 static int gopt_pid_file(const char *val);
 static int gopt_portmap_program(const char *val);
+static int gopt_nfs_proto(const char *val);
 static int gopt_nfs_retransmit_counter(const char *val);
 static int gopt_nfs_retry_interval(const char *val);
+static int gopt_nfs_vers(const char *val);
 static int gopt_nis_domain(const char *val);
 static int gopt_normalize_hostnames(const char *val);
 static int gopt_os(const char *val);
@@ -111,6 +114,7 @@ static int gopt_search_path(const char *val);
 static int gopt_selectors_on_default(const char *val);
 static int gopt_show_statfs_entries(const char *val);
 static int gopt_unmount_on_exit(const char *val);
+static int gopt_vendor(const char *val);
 static int process_global_option(const char *key, const char *val);
 static int process_regular_map(cf_map_t *cfm);
 static int process_regular_option(const char *section, const char *key, const char *val, cf_map_t *cfm);
@@ -137,6 +141,7 @@ static struct _func_map glob_functable[] = {
   {"debug_options",		gopt_debug_options},
   {"dismount_interval",		gopt_dismount_interval},
   {"fully_qualified_hosts",	gopt_fully_qualified_hosts},
+  {"full_os",			gopt_full_os},
   {"hesiod_base",		gopt_hesiod_base},
   {"karch",			gopt_karch},
   {"ldap_base",			gopt_ldap_base},
@@ -151,8 +156,10 @@ static struct _func_map glob_functable[] = {
   {"mount_type",		gopt_mount_type},
   {"pid_file",			gopt_pid_file},
   {"portmap_program",		gopt_portmap_program},
+  {"nfs_proto",			gopt_nfs_proto},
   {"nfs_retransmit_counter",	gopt_nfs_retransmit_counter},
   {"nfs_retry_interval",	gopt_nfs_retry_interval},
+  {"nfs_vers",			gopt_nfs_vers},
   {"nis_domain",		gopt_nis_domain},
   {"normalize_hostnames",	gopt_normalize_hostnames},
   {"os",			gopt_os},
@@ -165,6 +172,7 @@ static struct _func_map glob_functable[] = {
   {"selectors_on_default",	gopt_selectors_on_default},
   {"show_statfs_entries",	gopt_show_statfs_entries},
   {"unmount_on_exit",		gopt_unmount_on_exit},
+  {"vendor",			gopt_vendor},
   {NULL, NULL}
 };
 
@@ -389,6 +397,14 @@ gopt_dismount_interval(const char *val)
 }
 
 
+static int
+gopt_full_os(const char *val)
+{
+  gopt.op_sys_full = strdup((char *)val);
+  return 0;
+}
+
+
 static int
 gopt_fully_qualified_hosts(const char *val)
 {
@@ -550,6 +566,7 @@ gopt_mount_type(const char *val)
   if (STREQ(val, "autofs")) {
 #ifdef HAVE_FS_AUTOFS
     gopt.flags |= CFM_MOUNT_TYPE_AUTOFS;
+    amd_use_autofs++;
     return 0;
 #else /* not HAVE_FS_AUTOFS */
     fprintf(stderr, "conf: no autofs support available\n");
@@ -577,7 +594,7 @@ gopt_portmap_program(const char *val)
       gopt.portmap_program > AMQ_PROGRAM + 10) {
     gopt.portmap_program = AMQ_PROGRAM;
     set_amd_program_number(gopt.portmap_program);
-    fprintf(stderr, "conf: illegal amd program numver \"%s\"\n", val);
+    fprintf(stderr, "conf: illegal amd program number \"%s\"\n", val);
     return 1;
   }
 
@@ -586,6 +603,18 @@ gopt_portmap_program(const char *val)
 }
 
 
+static int
+gopt_nfs_proto(const char *val)
+{
+  if (STREQ(val, "udp") || STREQ(val, "tcp")) {
+    gopt.nfs_proto = strdup((char *)val);
+    return 0;
+  }
+  fprintf(stderr, "conf: illegal nfs_proto \"%s\"\n", val);
+  return 1;
+}
+
+
 static int
 gopt_nfs_retransmit_counter(const char *val)
 {
@@ -602,6 +631,20 @@ gopt_nfs_retry_interval(const char *val)
 }
 
 
+static int
+gopt_nfs_vers(const char *val)
+{
+  int i = atoi(val);
+
+  if (i == 2 || i == 3) {
+    gopt.nfs_vers = i;
+    return 0;
+  }
+  fprintf(stderr, "conf: illegal nfs_vers \"%s\"\n", val);
+  return 1;
+}
+
+
 static int
 gopt_nis_domain(const char *val)
 {
@@ -766,6 +809,14 @@ gopt_unmount_on_exit(const char *val)
 }
 
 
+static int
+gopt_vendor(const char *val)
+{
+  gopt.op_sys_vendor = strdup((char *)val);
+  return 0;
+}
+
+
 /*
  * Collect one entry for a regular map
  */
@@ -867,6 +918,7 @@ ropt_mount_type(const char *val, cf_map_t *cfm)
   if (STREQ(val, "autofs")) {
 #ifdef HAVE_FS_AUTOFS
     cfm->cfm_flags |= CFM_MOUNT_TYPE_AUTOFS;
+    amd_use_autofs++;
     return 0;
 #else /* not HAVE_FS_AUTOFS */
     fprintf(stderr, "conf: no autofs support available\n");
